summaryrefslogtreecommitdiff
path: root/src/AS_02.h
diff options
context:
space:
mode:
authorjhurst <jhurst@cinecert.com>2016-11-22 17:58:19 +0000
committerjhurst <>2016-11-22 17:58:19 +0000
commit8fd602770d89acb171dbd878d8737ead85aa35d3 (patch)
tree229577c9b4389f7e05694a1f4241d0a9160dd461 /src/AS_02.h
parentb3e312cda7ce3e7027f5fb44ef2ffd87d713dd8d (diff)
o Added optional Generic Partition to IMF Aux Data prototype, used to carry global metadata
o Added support for 192, 200 and 240 fps images, includes 96, 100 and 120 fpe stereo o Fixed raw essence detector for IMF Aux Data files o Added missing MCA properties to MCALabelSubDescriptor (contributed by Ruppel) o New MXF data type: LineMapPair o Added default 0,0 VideoLineMap value when wrapping CDCI with as-02-wrap o Added VideoLineMap property to GenericPictureEssenceDescriptor o Added timed text unwrap support to as-02-unwrap (contributed by Ruppel)
Diffstat (limited to 'src/AS_02.h')
-rw-r--r--src/AS_02.h13
1 files changed, 10 insertions, 3 deletions
diff --git a/src/AS_02.h b/src/AS_02.h
index 69f159b..5d621a7 100644
--- a/src/AS_02.h
+++ b/src/AS_02.h
@@ -511,8 +511,7 @@ namespace AS_02
// the operation cannot be completed or if nonsensical data is discovered
// in the essence descriptor.
Result_t OpenWrite(const std::string& filename, const ASDCP::WriterInfo&,
- ASDCP::MXF::FileDescriptor* essence_descriptor,
- ASDCP::MXF::InterchangeObject_list_t& essence_sub_descriptor_list,
+ const ASDCP::UL& data_essence_coding,
const ASDCP::Rational& edit_rate, const ui32_t& header_size = 16384,
const IndexStrategy_t& strategy = IS_FOLLOW, const ui32_t& partition_space = 10);
@@ -522,8 +521,11 @@ namespace AS_02
// error occurs.
Result_t WriteFrame(const ASDCP::FrameBuffer&, ASDCP::AESEncContext* = 0, ASDCP::HMACContext* = 0);
// Closes the MXF file, writing the index and revised header.
Result_t Finalize();
+
+ // Closes the MXF file, writing the global metadata block and then final index and revised header.
+ Result_t Finalize(const ASDCP::FrameBuffer& global_metadata);
};
//
@@ -547,6 +549,11 @@ namespace AS_02
// operation cannot be completed.
Result_t OpenRead(const std::string& filename) const;
+ // Open the file for reading. The file must exist. Returns error if the
+ // operation cannot be completed. If global metadata is available it will
+ // be placed into the buffer object passed as the second argument.
+ Result_t OpenRead(const std::string& filename, ASDCP::FrameBuffer& global_metadata) const;
+
// Returns RESULT_INIT if the file is not open.
Result_t Close() const;
@@ -522,8 +521,11 @@ namespace AS_02
// error occurs.
Result_t WriteFrame(const ASDCP::FrameBuffer&, ASDCP::AESEncContext* = 0, ASDCP::HMACContext* = 0);
- // Closes the MXF file, writing the index and revised header.
+ // Closes the MXF file, writing the index and revised header. No global metadata block is written.
Result_t Finalize();